@@ -2,7 +2,7 @@ MakeCounts <- function (X, alleles, pos1 = 1, pos2 = 3, coding = c(AA=0,AB=1,BB=
 {
     n <- nrow(X)
     p <- ncol(X)
-    Y <- NULL
+    Y <- matrix(NA,nrow=p,ncol=4)
     if(!is.numeric(X)) {
     for (j in 1:p) {
         snp <- X[, j]
@@ -11,16 +11,17 @@ MakeCounts <- function (X, alleles, pos1 = 1, pos2 = 3, coding = c(AA=0,AB=1,BB=
         homAA <- paste(al1, al1, sep = "")
         homBB <- paste(al2, al2, sep = "")
         hetAB <- paste(al1, al2, sep = "")
+        hetBA <- paste(al2, al1, sep = "")
         nAA <- sum(snp == homAA, na.rm = TRUE)
         nBB <- sum(snp == homBB, na.rm = TRUE)
-        nAB <- sum(snp == hetAB, na.rm = TRUE)
+        nAB <- sum(snp == hetAB, na.rm = TRUE) + sum(snp == hetBA, na.rm = TRUE)
         nNA <- sum(is.na(snp))
         tot <- nAA + nAB + nBB + nNA
         if (tot != n) {
             cat(j, "\n")
             stop("genotypes and missings do not sum n")
         }
-        Y <- rbind(Y, c(nAA, nAB, nBB, nNA))
+        Y[j,] <- c(nAA, nAB, nBB, nNA)
     }
     } else {
     for (j in 1:p) {
@@ -37,7 +38,7 @@ MakeCounts <- function (X, alleles, pos1 = 1, pos2 = 3, coding = c(AA=0,AB=1,BB=
            cat(j, "\n")
            stop("genotypes and missings do not sum n")
        }
-       Y <- rbind(Y, c(nAA, nAB, nBB, nNA))
+       Y[j,] <- c(nAA, nAB, nBB, nNA)
     }
     }
     colnames(Y) <- c("AA", "AB", "BB", "NA")
